// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/file_analysis/analyzer/x509/types.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_amd64_src_file_analysis_analyzer_x509_types_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_amd64_src_file_analysis_analyzer_x509_types_bif
#define _usr_obj_ports_zeek_8_1_1_build_amd64_src_file_analysis_analyzer_x509_types_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifType::Record::X509 { extern zeek::IntrusivePtr<zeek::RecordType> Certificate; }
namespace zeek::BifType::Record::X509 { extern zeek::IntrusivePtr<zeek::RecordType> Extension; }
namespace zeek::BifType::Record::X509 { extern zeek::IntrusivePtr<zeek::RecordType> BasicConstraints; }
namespace zeek::BifType::Record::X509 { extern zeek::IntrusivePtr<zeek::RecordType> SubjectAlternativeName; }
namespace zeek::BifType::Record::X509 { extern zeek::IntrusivePtr<zeek::RecordType> Result; }

#endif
