// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/analyzer/protocol/sip/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_sip_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_sip_events_bif
#define _usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_sip_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr sip_request; 
namespace zeek::BifEvent { void enqueue_sip_request(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> method, zeek::IntrusivePtr<zeek::StringVal> original_URI, zeek::IntrusivePtr<zeek::StringVal> version);  }
extern zeek::EventHandlerPtr sip_reply; 
namespace zeek::BifEvent { void enqueue_sip_reply(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> version, zeek_uint_t code, zeek::IntrusivePtr<zeek::StringVal> reason);  }
extern zeek::EventHandlerPtr sip_header; 
namespace zeek::BifEvent { void enqueue_sip_header(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek::IntrusivePtr<zeek::StringVal> name, zeek::IntrusivePtr<zeek::StringVal> value);  }
extern zeek::EventHandlerPtr sip_all_headers; 
namespace zeek::BifEvent { void enqueue_sip_all_headers(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek::IntrusivePtr<zeek::Val> hlist);  }
extern zeek::EventHandlerPtr sip_begin_entity; 
namespace zeek::BifEvent { void enqueue_sip_begin_entity(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig);  }
extern zeek::EventHandlerPtr sip_end_entity; 
namespace zeek::BifEvent { void enqueue_sip_end_entity(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig);  }

#endif
