// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/probabilistic/bloom-filter.bif (alternative mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_amd64_src_probabilistic_bloom_filter_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_amd64_src_probabilistic_bloom_filter_bif
#define _usr_obj_ports_zeek_8_1_1_build_amd64_src_probabilistic_bloom_filter_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_basic_init_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_basic_init2_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_counting_init_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_add_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_decrement_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_lookup_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_clear_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_merge_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_intersect_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr bloomfilter_internal_state_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
