// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/storage/storage-async.bif (alternative mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_amd64_src_storage_storage_async_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_amd64_src_storage_storage_async_bif
#define _usr_obj_ports_zeek_8_1_1_build_amd64_src_storage_storage_async_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifFunc::Storage::Async { extern zeek::ValPtr __open_backend_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Storage::Async { extern zeek::ValPtr __close_backend_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Storage::Async { extern zeek::ValPtr __put_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Storage::Async { extern zeek::ValPtr __get_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Storage::Async { extern zeek::ValPtr __erase_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
