// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/analyzer/protocol/netbios/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_netbios_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_netbios_events_bif
#define _usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_netbios_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr netbios_session_message; 
namespace zeek::BifEvent { void enqueue_netbios_session_message(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek_uint_t msg_type, zeek_uint_t data_len);  }
extern zeek::EventHandlerPtr netbios_session_request; 
namespace zeek::BifEvent { void enqueue_netbios_session_request(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> msg);  }
extern zeek::EventHandlerPtr netbios_session_accepted; 
namespace zeek::BifEvent { void enqueue_netbios_session_accepted(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> msg);  }
extern zeek::EventHandlerPtr netbios_session_rejected; 
namespace zeek::BifEvent { void enqueue_netbios_session_rejected(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> msg);  }
extern zeek::EventHandlerPtr netbios_session_raw_message; 
namespace zeek::BifEvent { void enqueue_netbios_session_raw_message(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek::IntrusivePtr<zeek::StringVal> msg);  }
extern zeek::EventHandlerPtr netbios_session_ret_arg_resp; 
namespace zeek::BifEvent { void enqueue_netbios_session_ret_arg_resp(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> msg);  }
extern zeek::EventHandlerPtr netbios_session_keepalive; 
namespace zeek::BifEvent { void enqueue_netbios_session_keepalive(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> msg);  }

#endif
