// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/input/readers/raw/raw.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_amd64_src_input_readers_raw_raw_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_amd64_src_input_readers_raw_raw_bif
#define _usr_obj_ports_zeek_8_1_1_build_amd64_src_input_readers_raw_raw_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifConst::InputRaw { extern zeek::IntrusivePtr<zeek::StringVal> record_separator; }

#endif
