// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/analyzer/protocol/ftp/functions.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_ftp_functions_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_ftp_functions_bif
#define _usr_obj_ports_zeek_8_1_1_build_amd64_src_analyzer_protocol_ftp_functions_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifType::Record { extern zeek::IntrusivePtr<zeek::RecordType> ftp_port; }
namespace zeek::BifFunc { extern zeek::ValPtr parse_ftp_port_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr parse_eftp_port_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr parse_ftp_pasv_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr parse_ftp_epsv_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr fmt_ftp_port_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
